@@ -60,10 +60,10 @@ diff $AUTOPKGTEST_TMP/video1.log $AUTOPKGTEST_TMP/video2.log
 check_result
 echo "[i] Extracting per-packet SHA256 hashes:"
 echo -n "    * video1.mp4... "
-ffmpeg -loglevel quiet -i $AUTOPKGTEST_TMP/video1.mp4 -f framehash - | grep -v " 1," > $AUTOPKGTEST_TMP/out1.sha256
+ffmpeg -loglevel quiet -i $AUTOPKGTEST_TMP/video1.mp4 -map 0:v -f framehash - > $AUTOPKGTEST_TMP/out1.sha256
 echo "done."
 echo -n "    * video2.mp4... "
-ffmpeg -loglevel quiet -i $AUTOPKGTEST_TMP/video2.mp4 -f framehash - | grep -v " 1," > $AUTOPKGTEST_TMP/out2.sha256
+ffmpeg -loglevel quiet -i $AUTOPKGTEST_TMP/video2.mp4 -map 0:v -f framehash - > $AUTOPKGTEST_TMP/out2.sha256
 echo "done."
 echo "[i] Generated hashes:"
 ls -lh $AUTOPKGTEST_TMP/*.sha256
